Stocks ML
===================================

Apply artificial intelligence to the stock market. StocksML can build an
entire trading strategy from scratch and simulate the performance of that
strategy against any specified benchmark.


.. toctree::
   :hidden:
   :maxdepth: 3

   quick_start
   api